# -*- coding: utf-8 -*-
import sys, base64

from bs4 import BeautifulSoup
try:
    from urllib2 import urlopen, Request
except ImportError:
    from urllib.request import urlopen, Request
try:
    from urlparse import urljoin
except ImportError:
    from urllib.parse import urljoin
try:
    from urllib import quote
except ImportError:
    from urllib.parse import quote
ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36'


def getsoup(url):
    request = Request(url, headers={'User-Agent': ua})
    if (2, 7, 3) <= sys.version_info < (3, 0) or (3, 2) <= sys.version_info < (4, 0):
        return BeautifulSoup(urlopen(request), 'html.parser')
    return BeautifulSoup(urlopen(request), 'html5lib')


def category(cat, page=1):
    url = 'https://www.97riju.net/vodtype/%s-%d/' % (cat, page)
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'riju97 100', 'error': str(e)}
    ret = []
    for e in soup.select('ul.fed-list-info li.fed-list-item'):
        plot = []
        e1 = e.select('a.fed-list-title')[0]
        img = e.select('a.fed-list-pics')[0]['data-original']
        for e2 in e.select('a.fed-list-pics span'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        plot.append(e.select('span.fed-list-desc')[0].text)
        plot = '\n'.join(plot)
        ret.append({'title': e1.text, 'url': urljoin(url, e1['href']), 'img': img, 'plot': plot})
    total = int(soup.select('a.fed-page-jump')[0]['data-total'])
    if int(page) < total:
        ret.append({'title': 'Next Page (%d)' % (page + 1), 'category': cat, 'page': page + 1})
    return ret


def search(s, page=1):
    url = 'https://www.97riju.net/vodsearch/%s----------%d---/' % (quote(s), page)
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'riju97 400', 'error': str(e)}
    ret = []
    for e in soup.select('dl.fed-deta-info'):
        plot = []
        e1 = e.select('dd.fed-deta-content a')[0]
        img = e.select('dt.fed-deta-images a')[0]['data-original']
        for e2 in e.select('dt.fed-deta-images span'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        for e2 in e.select('dd.fed-deta-content li'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        plot = '\n'.join(plot)
        ret.append({'title': e1.text, 'url': urljoin(url, e1['href']), 'img': img, 'plot': plot})
    total = soup.select('a.fed-page-jump')
    if total:
        if int(page) < int(total[0]['data-total']):
            ret.append({'title': 'Next Page (%d)' % (page + 1), 'search': s, 'page': page + 1})
    return ret


def vod(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'riju97 200', 'error': str(e)}
    ret = []
    for e1 in soup.select('div.fed-tabs-boxs div.fed-tabs-item'):
        sites = []
        i = 0
        for e2 in e1.select('div.fed-drop-tops ul.fed-part-rows li'):
            sites.append(e2.text.strip())
        for e2 in e1.select('div.fed-drop-btms ul.fed-drop-head.fed-part-rows'):
            e2.extract()
        for e2 in e1.select('div.fed-drop-btms div.fed-play-item ul.fed-part-rows'):
            ret1 = []
            for e3 in e2.select('li a'):
                ret1.append({e3.text: urljoin(url, e3['href'])})
            ret.append({sites[i]: ret1})
            i += 1
        for e2 in e1.select('div.fed-drop-btms div.fed-down-item ul.fed-part-rows li a'):
            ret.append({sites[i]: urljoin(url, e2['href'])})
            i += 1
            break
    return ret


def down(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'riju97 310', 'error': str(e)}
    ret = []
    for e1 in soup.select('div.fed-down-item'):
        for e2 in e1.select('ul.fed-drop-head.fed-part-rows'):
            e2.extract()
        for e2 in e1.select('ul.fed-part-rows li div.fed-tabs-submit a'):
            ret.append({e2.text: urljoin(url, e2['href'])})
    return ret


def play(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'riju97 300', 'error': str(e)}
    url = soup.select('iframe.fed-play-iframe')
    if not url:
        return {'code': 'riju97 301'}
    url = url[0]['data-play']
    url = base64.decodestring(url[3:])
    return {'title': '', 'url': url}
